unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Menus, PNCAToolbar, PNCACommon, pngimage, ExtCtrls, ComCtrls;

type
  TfrmMain = class(TForm)
    pumMainMenu: TPopupMenu;
    miNew: TMenuItem;
    miOpen: TMenuItem;
    miSave: TMenuItem;
    miSaveAs: TMenuItem;
    miN1: TMenuItem;
    miExit: TMenuItem;
    lbInfo: TLabel;
    pncaToolbar: TPNCAToolbar;
    imgBtnHover: TImage;
    rgStyle: TRadioGroup;
    gbCaption: TGroupBox;
    cbShowCaption: TCheckBox;
    rbCapLeft: TRadioButton;
    rbCapCenter: TRadioButton;
    rbCapRight: TRadioButton;
    imgNew: TImage;
    imgOpen: TImage;
    imgSave: TImage;
    imgHelp: TImage;
    tbPadding: TTrackBar;
    lbPadding: TLabel;
    Label1: TLabel;
    tbSpacing: TTrackBar;
    rgSepStyle: TRadioGroup;
    cbShowImage: TCheckBox;
    imgBtnDown: TImage;
    procedure miExitClick(Sender: TObject);
    procedure pncaToolbarDrawButton(Sender: TObject; AButton: TPNCAButton; const TargetCanvas: TCanvas; BtnRect, BarRect: TRect);
    procedure pncaToolbarBeforeDrawButton(Sender: TObject; AButton: TPNCAButton; const TargetCanvas: TCanvas; BtnRect,
      BarRect: TRect; var DefaultDrawing: TPNCADefaultDrawingKind);
    procedure pncaToolbarClick(Sender: TObject; AButton: TPNCAButton);
    procedure rgStyleClick(Sender: TObject);
    procedure cbShowCaptionClick(Sender: TObject);
    procedure rbCapLeftClick(Sender: TObject);
    procedure tbPaddingChange(Sender: TObject);
    procedure tbSpacingChange(Sender: TObject);
    procedure rgSepStyleClick(Sender: TObject);
    procedure cbShowImageClick(Sender: TObject);
  private
    { Private declarations }
    procedure UseCustomButtonPictures(UsePictures:Boolean);
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

uses
  PNCAUtils;

{$R *.dfm}

procedure TfrmMain.miExitClick(Sender: TObject);
begin
  Close;
end;

procedure TfrmMain.pncaToolbarDrawButton(Sender: TObject; AButton: TPNCAButton; const TargetCanvas: TCanvas; BtnRect, BarRect: TRect);
const
  mFlags = DT_SINGLELINE or DT_CENTER or DT_VCENTER or DT_END_ELLIPSIS;
begin
  if AButton=TPNCAToolbar(Sender).FirstButton then
  begin
    // draw the text of a first toolbar's button (application's button)
    Dec(BtnRect.Right,14); Dec(BtnRect.Bottom,4); // slightly modify the text position according to currently used button image
    if TPNCAToolbar(Sender).SmallSizeDrawing then
      Dec(BtnRect.Bottom);

    TargetCanvas.Font.Color := clWhite;
    if TPNCAToolbar(Sender).CompositedDrawing then
      DrawTextOnGlass(TargetCanvas, AButton.Caption, BtnRect, mFlags, TargetCanvas.Font.Color, 24)
    else
      DrawText(TargetCanvas.Handle, PChar(AButton.Caption), Length(AButton.Caption), BtnRect, mFlags);
  end;
end;

procedure TfrmMain.pncaToolbarBeforeDrawButton(Sender: TObject; AButton: TPNCAButton; const TargetCanvas: TCanvas; BtnRect,
  BarRect: TRect; var DefaultDrawing: TPNCADefaultDrawingKind);
begin
  case AButton.Style of
    pbsNone:
      if AButton<>TPNCAToolBar(Sender).FirstButton then
      begin
        if AButton.IsHovered  then
          DrawThemedImage(imgBtnHover.Picture.Graphic,TargetCanvas,BtnRect.Left+AButton.Padding-3,BtnRect.Top+AButton.Padding-3)
        else
        if AButton.Checked then
          DrawThemedImage(imgBtnDown.Picture.Graphic,TargetCanvas,BtnRect.Left+AButton.Padding-3,BtnRect.Top+AButton.Padding-3);
      end;
  end;
end;

procedure TfrmMain.pncaToolbarClick(Sender: TObject; AButton: TPNCAButton);
begin
  if AButton<>TPNCAToolbar(Sender).FirstButton then
  begin
    if AButton=TPNCAToolbar(Sender).Buttons[3] then
      AButton.Checked:=not AButton.Checked
    else
      ShowMessage('Button "'+AButton.Caption+'" clicked!');
  end;
end;

////////////////////////////////////////////////////////////////////////////////
procedure TfrmMain.UseCustomButtonPictures(UsePictures:Boolean);
begin
  if UsePictures then
  begin
    pncaToolBar.Buttons[2].Picture.Assign(imgNew.Picture);
    pncaToolBar.Buttons[3].Picture.Assign(imgOpen.Picture);
    pncaToolBar.Buttons[4].Picture.Assign(imgSave.Picture);
    pncaToolBar.Buttons[6].Picture.Assign(imgHelp.Picture);
  end
  else
  begin
    pncaToolBar.Buttons[2].Picture.Assign(nil);
    pncaToolBar.Buttons[3].Picture.Assign(nil);
    pncaToolBar.Buttons[4].Picture.Assign(nil);
    pncaToolBar.Buttons[6].Picture.Assign(nil);
  end;
end;

procedure TfrmMain.rgStyleClick(Sender: TObject);
const
  hideCustomPicts:set of TPNCAButtonStyle = [pbsCheckBox, pbsRadioButton, pbsDivider];
var
  s:TPNCAButtonStyle;
  i:Integer;
begin
  i:=rgStyle.ItemIndex;
  if i>5 then
    Inc(i,2) // skipped pbsSeparator and pbsDivider
  else
  if i>0 then
    inc(i);   // skipped pbsSeparator

  s:=TPNCAButtonStyle(i);
  pncaToolBar.Buttons.BeginUpdate;
  try
    if (s in hideCustomPicts)<>(pncaToolBar.Buttons[2].Style in hideCustomPicts) then
      cbShowImage.Checked:=not(s in hideCustomPicts);
    if s in [pbsLabel, pbsLinkLabel] then
      cbShowCaption.Checked:=True;

    for i := 1 to pncaToolBar.Buttons.Count-1 do
      if not (pncaToolBar.Buttons[i].Style in [pbsSeparator,pbsDivider]) then
      begin
        pncaToolBar.Buttons[i].Style:=s;
        if s=pbsLinkLabel then
          pncaToolBar.Buttons[i].HoverCursor:=crHandPoint
        else
          pncaToolBar.Buttons[i].HoverCursor:=crDefault;
      end;
  finally
    pncaToolBar.Buttons.EndUpdate;
  end;
end;

procedure TfrmMain.rgSepStyleClick(Sender: TObject);
var
  s:TPNCAButtonStyle;
begin
  case rgSepStyle.ItemIndex of
    1:s:=pbsDivider;
  else
    s:=pbsSeparator;
  end;
  pncaToolBar.Buttons.BeginUpdate;
  try
    pncaToolBar.Buttons[1].Style:=s;
    pncaToolBar.Buttons[5].Style:=s;
  finally
    pncaToolBar.Buttons.EndUpdate;
  end;
end;

procedure TfrmMain.cbShowCaptionClick(Sender: TObject);
var
  i:Integer;
begin
  pncaToolBar.Buttons.BeginUpdate;
  try
    for i := 1 to pncaToolBar.Buttons.Count-1 do
      if not (pncaToolBar.Buttons[i].Style in [pbsSeparator,pbsDivider]) then
        pncaToolBar.Buttons[i].ShowCaption:=cbShowCaption.Checked;
  finally
    pncaToolBar.Buttons.EndUpdate;
  end;
end;

procedure TfrmMain.cbShowImageClick(Sender: TObject);
begin
  UseCustomButtonPictures(cbShowImage.Checked);
end;

procedure TfrmMain.rbCapLeftClick(Sender: TObject);
var
  i:Integer;
  a:TAlignment;
begin
  case TRadioButton(Sender).Tag of
    1:a:=taLeftJustify;
    2:a:=taRightJustify;
  else
    a:=taCenter;
  end;
  pncaToolBar.Buttons.BeginUpdate;
  try
    for i := 1 to pncaToolBar.Buttons.Count-1 do
      pncaToolBar.Buttons[i].CaptionAlignment:=a;
  finally
    pncaToolBar.Buttons.EndUpdate;
  end;
end;

procedure TfrmMain.tbPaddingChange(Sender: TObject);
var
  i:Integer;
begin
  pncaToolBar.Buttons.BeginUpdate;
  try
    for i := 1 to pncaToolBar.Buttons.Count-1 do
      if not (pncaToolBar.Buttons[i].Style in [pbsSeparator,pbsDivider]) then
        pncaToolBar.Buttons[i].Padding:=tbPadding.Position;
  finally
    pncaToolBar.Buttons.EndUpdate;
  end;
end;

procedure TfrmMain.tbSpacingChange(Sender: TObject);
var
  i:Integer;
begin
  pncaToolBar.Buttons.BeginUpdate;
  try
    for i := 1 to pncaToolBar.Buttons.Count-1 do
      if not (pncaToolBar.Buttons[i].Style in [pbsSeparator,pbsDivider]) then
        pncaToolBar.Buttons[i].Spacing:=tbSpacing.Position;
  finally
    pncaToolBar.Buttons.EndUpdate;
  end;
end;

end.
